#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#############################################################################################
# This plugin checks if there are any threats found by Windows Defender and System Center   #
# Endpoint Protection. It creates one service called "AV threats Defender" or               #
# "AV threats SCEP". The service will be in CRIT state, if a threat was found. You can      #
# Threats can be acknowledged by activating the rule "Defender acknowledged threats" and    #
# adding the DetectionID to it.                                                             # 
# ----------------------------------------------------------------------------------------- #
# Author: Michael Dvorak - specialis IT GmbH                                                #
# Version: 1.0 - 2021-12-30 - initial version                                               #
#############################################################################################

# Example of section data:
# <<<spit_defender_threats>>>
# 10 {906AC34E-80CD-497F-83A3-B55B8FA548FE} DESKTOP-LGNR9K1\admin 29.12.2021 09:18:10 Unknown C:\Users\admin\Downloads\eicar.com
# 10 {4A43C4F0-A970-40F4-95AC-BC872C2FE75F} DESKTOP-LGNR9K1\admin 30.12.2021 12:59:28 Unknown C:\Users\admin\Downloads\eicar

from .agent_based_api.v1 import *
import pprint

def discover_spit_defender_threats(section):
    if int(section[0][0]) == 6:
        avname="SCEP"
    else:
        avname="Defender"
    yield Service(item=avname)

def check_spit_defender_threats(item,params,section):
    
    if len(params)>0:
        acknowledgedIds = params["id_patterns"]
    else:
        acknowledgedIds = []
        
    detectionSum = []
    detectionDet = []
    threatsFound = 0
    
    for OsVersion, DetectionID, DomainUser, DetectionDate, DetectionTime, ProcessName, FileName in section:
        
        if DetectionID != "{no_threats_found}":
            if DetectionID not in acknowledgedIds:
                threatsFound += 1
                FileName = FileName.replace('%20',' ')
                UserName = DomainUser.split('\\')
                detectionSum.append(f"[File:{FileName} User:{UserName[1]} Time:{DetectionDate} {DetectionTime}]")
                detectionDet.append(f"DetectionID: {DetectionID}\nFile: {FileName}\nUser: {DomainUser}\nTime: {DetectionDate} {DetectionTime}")
    
    if threatsFound>0:
        s = State.CRIT
        mess_sum = f'Possible Virus found: ({threatsFound}) '
        mess_sum += ', '.join(detectionSum)
        mess_det = '\n-------------------------------------------------------------------------------------------------------\n'.join(detectionDet)
    else:
        s = State.OK
        mess_sum = "No threats found!"
        mess_det = "No threats found!"
        
    yield Result(state=s,summary=mess_sum,details=mess_det)
    
register.check_plugin(
    name="spit_defender_threats",
    service_name="AV threats (%s)",
    discovery_function=discover_spit_defender_threats,
    check_function=check_spit_defender_threats,
    check_default_parameters={},
    check_ruleset_name="spit_defender_threats",
)
